@@ -448,7 +448,6 @@ class MixinBigQueryBulkComplete(object):
 
 class BigQueryLoadTask(MixinBigQueryBulkComplete, luigi.Task):
     """Load data into BigQuery from GCS."""
-
     @property
     def source_format(self):
         """The source format to use (see :py:class:`SourceFormat`)."""
@@ -470,7 +469,7 @@ class BigQueryLoadTask(MixinBigQueryBulkComplete, luigi.Task):
     def schema(self):
         """Schema in the format defined at https://cloud.google.com/bigquery/docs/reference/v2/jobs#configuration.load.schema.
 
-        If the value is falsy, it is omitted and inferred by BigQuery, which only works for AVRO and CSV inputs."""
+        If the value is falsy, it is omitted and inferred by BigQuery."""
         return []
 
     @property
@@ -560,6 +559,8 @@ class BigQueryLoadTask(MixinBigQueryBulkComplete, luigi.Task):
 
         if self.schema:
             job['configuration']['load']['schema'] = {'fields': self.schema}
+        else:
+            job['configuration']['load']['autodetect'] = True
 
         bq_client.run_job(output.table.project_id, job, dataset=output.table.dataset)
 
